@@ -1,7 +1,7 @@
 (*
     The environment file to expand the examples.
 
-    It is in ``Caml'' style and uses simple Caml bindings of the form:
+    It is in ``Caml'' style and uses simple Caml-like bindings of the form:
 
     let name = value;;
 *)
@@ -14,15 +14,23 @@ let X = "hello";;
 
 let Y = 1;;
 
+let definition_on_2_lines =
+  "J'espre que
+ a marche!";;
+
 let a_long_definition_can_spread_on_more_than_one_line = "\
 ca marche
 mme sur
 plusieurs
 lignes!";;
 
+let short_def = "court!";;
+
 (* Defining an alias for this over long identifier. *)
 let long_def = a_long_definition_can_spread_on_more_than_one_line;;
 
+let shorter_def = "c";;
+
 (* Rocquencourt Campus's address. *)
 let inria_address = "\
 INRIA<BR>\n\
@@ -37,7 +45,17 @@ let hotel = "La Datcha";;
 let hotel_address = "\
 128 rue de la souris qui se repose\n\
 78000 Versailles\n\
-France";;
+France"
+;;
+
+(* Also check that newline escapes are properly handled (i.e. `` la
+   Caml''). *)
+let newline_escaped_string = "\
+    1\
+    2\
+    3\
+    "
+;;
 
 (****** (* Nested comments are properly handled *) *******)
 (****** (* Including when "nasty strings are added inside *)"
@@ -46,4 +64,9 @@ France";;
 
 let advi_version = "1.60";;
 
+# We are obliged to fix the htmlc version, in order to get reproducible tests!
+let htmlc_version = "1.70";;
+
+let package_version = htmlc_version;;
+
 let last_variable = true;;
